@@ -57,6 +57,18 @@ class InvalidParameterValueError(SushyError):
                'Valid values are: %(valid_values)s')
 
 
+class ArchiveParsingError(SushyError):
+    message = 'Failed parsing archive "%(path)s": %(error)s'
+
+
+class ExtensionError(SushyError):
+    message = ('Sushy Extension Error: %(error)s')
+
+
+class OEMExtensionNotFoundError(SushyError):
+    message = 'No %(resource)s OEM extension found by name "%(name)s".'
+
+
 class HTTPError(SushyError):
     """Basic exception for HTTP errors"""
 
@@ -85,11 +97,13 @@ class HTTPError(SushyError):
                          self.status_code})
             error = 'unknown error'
         else:
-            # TODO(dtantsur): parse @Message.ExtendedInfo
             self.body = body.get('error', {})
             self.code = self.body.get('code', 'Base.1.0.GeneralError')
             self.detail = self.body.get('message')
-            error = '%s: %s' % (self.code, self.detail or 'unknown error')
+            ext_info = self.body.get('@Message.ExtendedInfo', [{}])
+            message = self._get_most_severe_msg(ext_info)
+            self.detail = message or self.detail
+            error = '%s: %s' % (self.code, self.detail or 'unknown error.')
 
         kwargs = {'method': method, 'url': url, 'code': self.status_code,
                   'error': error}
@@ -97,6 +111,16 @@ class HTTPError(SushyError):
                   'status code: %(code)s, error: %(error)s', kwargs)
         super(HTTPError, self).__init__(**kwargs)
 
+    @staticmethod
+    def _get_most_severe_msg(extended_info):
+        if not isinstance(extended_info, list):
+            return extended_info.get('Message', None)
+        if len(extended_info) > 0:
+            for sev in ['Critical', 'Warning']:
+                for i, m in enumerate(extended_info):
+                    if m.get('Severity') == sev:
+                        return m.get('Message')
+
 
 class BadRequestError(HTTPError):
     pass
@@ -115,6 +139,11 @@ class AccessError(HTTPError):
     pass
 
 
+class MissingXAuthToken(HTTPError):
+    message = ('No X-Auth-Token returned from remote host when '
+               'attempting to establish a session. Error: %(error)s')
+
+
 def raise_for_response(method, url, response):
     """Raise a correct error class, if needed."""
     if response.status_code < http_client.BAD_REQUEST:
