@@ -30,6 +30,7 @@ from sushy.resources.sessionservice import session
 from sushy.resources.sessionservice import sessionservice
 from sushy.resources.system import system
 from sushy.resources.updateservice import updateservice
+from sushy import utils
 
 LOG = logging.getLogger(__name__)
 
@@ -138,12 +139,12 @@ class Sushy(base.ResourceBase):
         super(Sushy, self).__init__(
             connector or sushy_connector.Connector(base_url, verify=verify),
             path=self._root_prefix)
+        self._public_connector = public_connector or requests
+        self._language = language
         self._base_url = base_url
         self._auth = auth
         self._auth.set_context(self, self._conn)
         self._auth.authenticate()
-        self._public_connector = public_connector or requests
-        self._language = language
 
     def __del__(self):
         if self._auth:
@@ -155,9 +156,15 @@ class Sushy(base.ResourceBase):
                             'with %s: %s', self._base_url, ex)
             self._auth = None
 
-    def _parse_attributes(self):
-        super(Sushy, self)._parse_attributes()
-        self.redfish_version = self.json.get('RedfishVersion')
+    def _parse_attributes(self, json_doc):
+        """Parse the attributes of a resource.
+
+        Parsed JSON fields are set to `self` as declared in the class.
+
+        :param json_doc: parsed JSON document in form of Python types
+        """
+        super(Sushy, self)._parse_attributes(json_doc)
+        self.redfish_version = json_doc.get('RedfishVersion')
 
     def get_system_collection(self):
         """Get the SystemCollection object
@@ -170,8 +177,10 @@ class Sushy(base.ResourceBase):
             raise exceptions.MissingAttributeError(
                 attribute='Systems/@odata.id', resource=self._path)
 
-        return system.SystemCollection(self._conn, self._systems_path,
-                                       redfish_version=self.redfish_version)
+        return system.SystemCollection(
+            self._conn, self._systems_path,
+            redfish_version=self.redfish_version,
+            registries=self.registries)
 
     def get_system(self, identity):
         """Given the identity return a System object
@@ -181,7 +190,7 @@ class Sushy(base.ResourceBase):
         """
         return system.System(self._conn, identity,
                              redfish_version=self.redfish_version,
-                             registries=self._get_message_registries())
+                             registries=self.registries)
 
     def get_chassis_collection(self):
         """Get the ChassisCollection object
@@ -195,7 +204,8 @@ class Sushy(base.ResourceBase):
                 attribute='Chassis/@odata.id', resource=self._path)
 
         return chassis.ChassisCollection(self._conn, self._chassis_path,
-                                         redfish_version=self.redfish_version)
+                                         redfish_version=self.redfish_version,
+                                         registries=self.registries)
 
     def get_chassis(self, identity):
         """Given the identity return a Chassis object
@@ -204,7 +214,8 @@ class Sushy(base.ResourceBase):
         :returns: The Chassis object
         """
         return chassis.Chassis(self._conn, identity,
-                               redfish_version=self.redfish_version)
+                               redfish_version=self.redfish_version,
+                               registries=self.registries)
 
     def get_fabric_collection(self):
         """Get the FabricCollection object
@@ -218,7 +229,8 @@ class Sushy(base.ResourceBase):
                 attribute='Fabrics/@odata.id', resource=self._path)
 
         return fabric.FabricCollection(self._conn, self._fabrics_path,
-                                       redfish_version=self.redfish_version)
+                                       redfish_version=self.redfish_version,
+                                       registries=self.registries)
 
     def get_fabric(self, identity):
         """Given the identity return a Fabric object
@@ -227,7 +239,8 @@ class Sushy(base.ResourceBase):
         :returns: The Fabric object
         """
         return fabric.Fabric(self._conn, identity,
-                             redfish_version=self.redfish_version)
+                             redfish_version=self.redfish_version,
+                             registries=self.registries)
 
     def get_manager_collection(self):
         """Get the ManagerCollection object
@@ -241,7 +254,8 @@ class Sushy(base.ResourceBase):
                 attribute='Managers/@odata.id', resource=self._path)
 
         return manager.ManagerCollection(self._conn, self._managers_path,
-                                         redfish_version=self.redfish_version)
+                                         redfish_version=self.redfish_version,
+                                         registries=self.registries)
 
     def get_manager(self, identity):
         """Given the identity return a Manager object
@@ -250,7 +264,8 @@ class Sushy(base.ResourceBase):
         :returns: The Manager object
         """
         return manager.Manager(self._conn, identity,
-                               redfish_version=self.redfish_version)
+                               redfish_version=self.redfish_version,
+                               registries=self.registries)
 
     def get_session_service(self):
         """Get the SessionService object
@@ -267,14 +282,25 @@ class Sushy(base.ResourceBase):
             self._conn, self._session_service_path,
             redfish_version=self.redfish_version)
 
+    def get_sessions_path(self):
+        """Returns the Sessions url"""
+
+        try:
+            links_url = self.json.get('Links')
+            return links_url['Sessions']['@odata.id']
+        except (TypeError, KeyError):
+            raise exceptions.MissingAttributeError(
+                attribute='Links/Sessions/@data.id', resource=self.path)
+
     def get_session(self, identity):
         """Given the identity return a Session object
 
         :param identity: The identity of the session resource
         :returns: The Session object
         """
-        return session.Session(self._conn, identity,
-                               redfish_version=self.redfish_version)
+        return session.Session(
+            self._conn, identity,
+            redfish_version=self.redfish_version, registries=self.registries)
 
     def get_update_service(self):
         """Get the UpdateService object
@@ -287,7 +313,8 @@ class Sushy(base.ResourceBase):
 
         return updateservice.UpdateService(
             self._conn, self._update_service_path,
-            redfish_version=self.redfish_version)
+            redfish_version=self.redfish_version,
+            registries=self.registries)
 
     def _get_registry_collection(self):
         """Get MessageRegistryFileCollection object
@@ -315,9 +342,11 @@ class Sushy(base.ResourceBase):
             raise exceptions.MissingAttributeError(
                 attribute='CompositionService/@odata.id',
                 resource=self._path)
+
         return compositionservice.CompositionService(
             self._conn, self._composition_service_path,
-            redfish_version=self.redfish_version)
+            redfish_version=self.redfish_version,
+            registries=self.registries)
 
     def _get_standard_message_registry_collection(self):
         """Load packaged standard message registries
@@ -337,22 +366,26 @@ class Sushy(base.ResourceBase):
 
         return message_registries
 
-    def _get_message_registries(self):
+    @property
+    @utils.cache_it
+    def registries(self):
         """Gets and combines all message registries together
 
         Fetches all registries if any provided by Redfish service
         and combines together with packaged standard registries.
 
         :returns: dict of combined message registries where key is
-        Registry_name.Major_version.Minor_version and value is registry
-        itself.
+            Registry_name.Major_version.Minor_version and value is registry
+            itself.
         """
-
         standard = self._get_standard_message_registry_collection()
+
         registries = {r.registry_prefix + '.' +
                       r.registry_version.rsplit('.', 1)[0]: r
                       for r in standard if r.language == self._language}
+
         registry_col = self._get_registry_collection()
+
         if registry_col:
             provided = registry_col.get_members()
             registries.update({r.registry: r.get_message_registry(
