@@ -16,6 +16,7 @@ import json
 import mock
 
 from dateutil import parser
+from six.moves import http_client
 
 from sushy import exceptions
 from sushy.resources.registry import message_registry
@@ -30,14 +31,14 @@ class BiosTestCase(base.TestCase):
         super(BiosTestCase, self).setUp()
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/bios.json') as f:
-            bios_json = json.load(f)
+            self.bios_json = json.load(f)
         with open('sushy/tests/unit/json_samples/bios_settings.json') as f:
-            bios_settings_json = json.load(f)
+            self.bios_settings_json = json.load(f)
 
         self.conn.get.return_value.json.side_effect = [
-            bios_json,
-            bios_settings_json,
-            bios_settings_json]
+            self.bios_json,
+            self.bios_settings_json,
+            self.bios_settings_json]
 
         conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/message_registry.json') as f:
@@ -52,7 +53,7 @@ class BiosTestCase(base.TestCase):
             redfish_version='1.0.2')
 
     def test__parse_attributes(self):
-        self.sys_bios._parse_attributes()
+        self.sys_bios._parse_attributes(self.bios_json)
         self.assertEqual('1.0.2', self.sys_bios.redfish_version)
         self.assertEqual('BIOS', self.sys_bios.identity)
         self.assertEqual('BIOS Configuration Current Settings',
@@ -150,13 +151,49 @@ class BiosTestCase(base.TestCase):
         self.assertRaisesRegex(
             exceptions.MissingAttributeError,
             'attribute Actions/#Bios.ResetBios/target',
-            self.sys_bios._parse_attributes)
+            self.sys_bios._parse_attributes, self.bios_json)
 
     def test_reset_bios(self):
         self.sys_bios.reset_bios()
         self.sys_bios._conn.post.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2/BIOS/Actions/Bios.ResetBios')
 
+    def test_reset_bios_handle_http_error_415(self):
+
+        target_uri = (
+            '/redfish/v1/Systems/437XR1138R2/BIOS/Actions/Bios.ResetBios')
+        self.conn.post.side_effect = [exceptions.HTTPError(
+            method='POST', url=target_uri, response=mock.MagicMock(
+                status_code=http_client.UNSUPPORTED_MEDIA_TYPE)), '200']
+        post_calls = [
+            mock.call(target_uri), mock.call(target_uri, data={})]
+        self.sys_bios.reset_bios()
+        self.sys_bios._conn.post.assert_has_calls(post_calls)
+
+    def test_reset_bios_handle_http_error_400(self):
+
+        target_uri = (
+            '/redfish/v1/Systems/437XR1138R2/BIOS/Actions/Bios.ResetBios')
+        self.conn.post.side_effect = [exceptions.HTTPError(
+            method='POST', url=target_uri, response=mock.MagicMock(
+                status_code=http_client.BAD_REQUEST)), '200']
+        post_calls = [
+            mock.call(target_uri), mock.call(target_uri, data={})]
+        self.sys_bios.reset_bios()
+        self.sys_bios._conn.post.assert_has_calls(post_calls)
+
+    def test_reset_bios_handle_http_error_405(self):
+
+        target_uri = (
+            '/redfish/v1/Systems/437XR1138R2/BIOS/Actions/Bios.ResetBios')
+        self.conn.post.side_effect = exceptions.HTTPError(
+            method='POST', url=target_uri, response=mock.MagicMock(
+                status_code=http_client.METHOD_NOT_ALLOWED))
+        self.assertRaises(
+            exceptions.HTTPError,
+            self.sys_bios.reset_bios)
+        self.sys_bios._conn.post.assert_called_once_with(target_uri)
+
     def test__get_change_password_element(self):
         value = self.sys_bios._get_change_password_element()
         self.assertEqual("/redfish/v1/Systems/437XR1138R2/BIOS/Actions/"
@@ -177,7 +214,7 @@ class BiosTestCase(base.TestCase):
         self.assertRaisesRegex(
             exceptions.MissingAttributeError,
             'attribute Actions/#Bios.ChangePassword/target',
-            self.sys_bios._parse_attributes)
+            self.sys_bios._parse_attributes, self.bios_json)
 
     def test_change_password(self):
         self.sys_bios.change_password('newpassword',
